## Copyright (C) 2011 Moacir Ponti Jr
## 
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
## 
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
## 
## You should have received a copy of the GNU General Public License
## along with Octave; see the file COPYING.  If not, see
## <http://www.gnu.org/licenses/>.

## localmaxima
% -------------------------------------------------------------------------------
% Computes the points of local maxima in an image, removing low response points
%    input: H = image
% 	    k = region k x k to search for the maxima
%
%    output: P = binary image with local maxima points
% -------------------------------------------------------------------------------
## Author: Moacir Ponti Jr <moacir@icmc.usp.br>
## Created: 2011-10-28
function [ P ] = localmaxima(H, k)

    [n,m] = size(H);

    if mod(k,2) == 0
	k = k +1;
    end

    % gera matriz de uns com zero no centro para retornar os maximos locais
    MM = ones(k,k);
    MM(round((k*k)/2)) = 0;
    Hc = H >= imdilate(H, MM);

    % remove as respostas nos 5 pixels proximos a borda
     %%%%%%%%%%%%%%%
    % seu código aqui!!!
    %%%%%%%%%%%%%%%

    % computa a média de cada ponto da imagem em uma janela k x k
    Md = filter2(repmat(1/(k*k),k,k), H);

    % computa o desvio padrão em cada ponto (H - média)
    Sti = H - Md;

    % computa o desvio padrão da imagem (completa)
    stdv = std( H(:) );
 
    % encontra os locais onde o desvio padrão é maior do que metade do desvio padrão da imagem (multiplicado por um threshold)
    %%%%%%%%%%%%%%%
    % seu código aqui!!!
    %%%%%%%%%%%%%%%

    % monta matriz de pontos de maximo
    P = zeros(n,m);
    P(ind_cp) = Hc(ind_cp); % copia apenas os pontos de desvio padrão alto

endfunction
